@@ -22,13 +22,15 @@
 QGraphicsEffect *kImageAnnotator::ImageEffectFactory::create(kImageAnnotator::ImageEffects effect)
 {
 	switch (effect) {
-		case ImageEffects::NoEffect:
-			return new NoImageEffect;
 		case ImageEffects::DropShadow:
 			return new DropShadowImageEffect;
 		case ImageEffects::Border:
 			return new BorderImageEffect;
 		case ImageEffects::Grayscale:
 			return new GrayscaleImageEffect;
+		case ImageEffects::InvertColor:
+			return new InvertColorImageEffect;
+		default:
+			return new NoImageEffect;
 	}
 }
