@@ -21,7 +21,8 @@
 
 namespace kImageAnnotator {
 
-AnnotationPen::AnnotationPen(const QPointF &startPosition, const PropertiesPtr &properties) : AbstractAnnotationPath(startPosition, properties)
+AnnotationPen::AnnotationPen(const QPointF &startPosition, const PropertiesPtr &properties) :
+	AbstractAnnotationPath(startPosition, properties)
 {
 	updateShape();
 }
