@@ -44,6 +44,13 @@
         <translation>Eliminar</translation>
     </message>
 </context>
+<context>
+    <name>kImageAnnotator::AnnotationControlsWidget</name>
+    <message>
+        <source>Controls</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>kImageAnnotator::AnnotationGeneralSettings</name>
     <message>
@@ -88,6 +95,14 @@
         <source>Item Settings</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Scale</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Opacity</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>kImageAnnotator::AnnotationTabContextMenu</name>
@@ -130,6 +145,37 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>kImageAnnotator::Controls</name>
+    <message>
+        <source>Undo</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Redo</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Crop</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scale</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rotate</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Modify canvas</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cut</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>kImageAnnotator::CropWidget</name>
     <message>
@@ -157,6 +203,25 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>kImageAnnotator::CutWidget</name>
+    <message>
+        <source>Vertical</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Horizontal</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Apply</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished">Cancelar</translation>
+    </message>
+</context>
 <context>
     <name>kImageAnnotator::FillModePicker</name>
     <message>
@@ -457,5 +522,17 @@ Rotating by non 90° multipliers might introduce loss of quality.</source>
         <source>Reset Zoom (%1)</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Reset Zoom</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Fit Image</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Fit image to view (%1)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
